pub struct feesCall {
pub perp: <PerpConfig as SolType>::RustType,
}Expand description
Function with signature fees(((address,address,uint24,int24,address),address,address,address,address,address,address,address)) and selector 0x866fdec8.
function fees(PerpManager.PerpConfig calldata perp) external returns (uint24 cFee, uint24 insFee, uint24 lpFee);Fields
perp: <PerpConfig as SolType>::RustTypeTrait Implementations
Sourceimpl SolCall for feesCall
impl SolCall for feesCall
Sourceconst SIGNATURE: &'static str = "fees(((address,address,uint24,int24,address),address,address,address,address,address,address,address))"
const SIGNATURE: &'static str = "fees(((address,address,uint24,int24,address),address,address,address,address,address,address,address))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (PerpConfig,)
type Parameters<'a> = (PerpConfig,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<feesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<feesCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = feesReturn
type Return = feesReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Uint<24>, Uint<24>, Uint<24>)
type ReturnTuple<'a> = (Uint<24>, Uint<24>, Uint<24>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<feesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<feesCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.