pub struct cfgsReturn {
pub _0: <PerpConfig as SolType>::RustType,
}Expand description
Returns the perp configuration for a given pool ID.
Container type for the return parameters of the cfgs(bytes32) function.
Fields
_0: <PerpConfig as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for cfgsReturn
impl Clone for cfgsReturn
Sourcefn clone(&self) -> cfgsReturn
fn clone(&self) -> cfgsReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for cfgsReturn
impl RefUnwindSafe for cfgsReturn
impl Send for cfgsReturn
impl Sync for cfgsReturn
impl Unpin for cfgsReturn
impl UnsafeUnpin for cfgsReturn
impl UnwindSafe for cfgsReturn