pub struct takerOpenInterestCall {
pub perpId: FixedBytes<32>,
}Expand description
Returns taker long and short open interest.
Function with signature takerOpenInterest(bytes32) and selector 0x77d3b282.
function takerOpenInterest(bytes32 perpId) external view returns (uint128 longOI, uint128 shortOI);Fields
perpId: FixedBytes<32>Trait Implementations
Sourceimpl Clone for takerOpenInterestCall
impl Clone for takerOpenInterestCall
Sourcefn clone(&self) -> takerOpenInterestCall
fn clone(&self) -> takerOpenInterestCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for takerOpenInterestCall
impl SolCall for takerOpenInterestCall
Sourcetype Parameters<'a> = (FixedBytes<32>,)
type Parameters<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<takerOpenInterestCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<takerOpenInterestCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = takerOpenInterestReturn
type Return = takerOpenInterestReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Uint<128>, Uint<128>)
type ReturnTuple<'a> = (Uint<128>, Uint<128>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<takerOpenInterestCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<takerOpenInterestCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.