pub enum PerpManagerEvents {
PerpCreated(PerpCreated),
PositionOpened(PositionOpened),
NotionalAdjusted(NotionalAdjusted),
MarginAdjusted(MarginAdjusted),
PositionClosed(PositionClosed),
FeesModuleRegistered(FeesModuleRegistered),
MarginRatiosModuleRegistered(MarginRatiosModuleRegistered),
LockupPeriodModuleRegistered(LockupPeriodModuleRegistered),
SqrtPriceImpactLimitModuleRegistered(SqrtPriceImpactLimitModuleRegistered),
}Expand description
Container for all the PerpManager events.
Variants
PerpCreated(PerpCreated)
PositionOpened(PositionOpened)
NotionalAdjusted(NotionalAdjusted)
MarginAdjusted(MarginAdjusted)
PositionClosed(PositionClosed)
FeesModuleRegistered(FeesModuleRegistered)
MarginRatiosModuleRegistered(MarginRatiosModuleRegistered)
LockupPeriodModuleRegistered(LockupPeriodModuleRegistered)
SqrtPriceImpactLimitModuleRegistered(SqrtPriceImpactLimitModuleRegistered)
Implementations
Sourceimpl PerpManagerEvents
impl PerpManagerEvents
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.