pub struct PositionClosed {Show 18 fields
pub perpId: FixedBytes<32>,
pub sqrtPriceX96: U256,
pub longOI: U256,
pub shortOI: U256,
pub posId: U256,
pub wasMaker: bool,
pub wasLiquidated: bool,
pub wasPartialClose: bool,
pub exitPerpDelta: I256,
pub exitUsdDelta: I256,
pub tickLower: I24,
pub tickUpper: I24,
pub netUsdDelta: I256,
pub funding: I256,
pub utilizationFee: U256,
pub adl: U256,
pub liquidationFee: U256,
pub netMargin: I256,
}Expand description
Event with signature PositionClosed(bytes32,uint256,uint256,uint256,uint256,bool,bool,bool,int256,int256,int24,int24,int256,int256,uint256,uint256,uint256,int256) and selector 0x992fd4768aecc604adbc53b59e87a6d193226e9001b2086cc5f3b4addcf82fd5.
event PositionClosed(bytes32 perpId, uint256 sqrtPriceX96, uint256 longOI, uint256 shortOI, uint256 posId, bool wasMaker, bool wasLiquidated, bool wasPartialClose, int256 exitPerpDelta, int256 exitUsdDelta, int24 tickLower, int24 tickUpper, int256 netUsdDelta, int256 funding, uint256 utilizationFee, uint256 adl, uint256 liquidationFee, int256 netMargin);Fields
perpId: FixedBytes<32>sqrtPriceX96: U256longOI: U256shortOI: U256posId: U256wasMaker: boolwasLiquidated: boolwasPartialClose: boolexitPerpDelta: I256exitUsdDelta: I256tickLower: I24tickUpper: I24netUsdDelta: I256funding: I256utilizationFee: U256adl: U256liquidationFee: U256netMargin: I256Trait Implementations
Sourceimpl Clone for PositionClosed
impl Clone for PositionClosed
Sourcefn clone(&self) -> PositionClosed
fn clone(&self) -> PositionClosed
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<&PositionClosed> for LogData
impl From<&PositionClosed> for LogData
Sourcefn from(this: &PositionClosed) -> LogData
fn from(this: &PositionClosed) -> LogData
Converts to this type from the input type.
Sourceimpl IntoLogData for PositionClosed
impl IntoLogData for PositionClosed
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a
LogData object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a
LogData object.Sourceimpl SolEvent for PositionClosed
impl SolEvent for PositionClosed
Sourceconst SIGNATURE: &'static str = "PositionClosed(bytes32,uint256,uint256,uint256,uint256,bool,bool,bool,int256,int256,int24,int24,int256,int256,uint256,uint256,uint256,int256)"
const SIGNATURE: &'static str = "PositionClosed(bytes32,uint256,uint256,uint256,uint256,bool,bool,bool,int256,int256,int24,int24,int256,int256,uint256,uint256,uint256,int256)"
The event’s ABI signature. Read more
Sourceconst SIGNATURE_HASH: B256
const SIGNATURE_HASH: B256
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moreSourcetype DataTuple<'a> = (FixedBytes<32>, Uint<256>, Uint<256>, Uint<256>, Uint<256>, Bool, Bool, Bool, Int<256>, Int<256>, Int<24>, Int<24>, Int<256>, Int<256>, Uint<256>, Uint<256>, Uint<256>, Int<256>)
type DataTuple<'a> = (FixedBytes<32>, Uint<256>, Uint<256>, Uint<256>, Uint<256>, Bool, Bool, Bool, Int<256>, Int<256>, Int<24>, Int<24>, Int<256>, Int<256>, Uint<256>, Uint<256>, Uint<256>, Int<256>)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
Sourcetype DataToken<'a> = <<PositionClosed as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<PositionClosed as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The
TokenSeq type corresponding to the tuple.Sourcetype TopicList = (FixedBytes<32>,)
type TopicList = (FixedBytes<32>,)
The underlying tuple type which represents this event’s topics. Read more
Sourcefn new(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Self
fn new( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Self
Convert decoded rust data to the event type. Read more
Sourcefn check_signature(
topics: &<Self::TopicList as SolType>::RustType,
) -> Result<()>
fn check_signature( topics: &<Self::TopicList as SolType>::RustType, ) -> Result<()>
Check that the event’s signature matches the given topics.
Sourcefn tokenize_body(&self) -> Self::DataToken<'_>
fn tokenize_body(&self) -> Self::DataToken<'_>
Tokenize the event’s non-indexed parameters.
Sourcefn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<()>
Encode the topics of this event into the given buffer. Read more
Sourcefn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
Sourcefn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
Sourcefn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
Sourcefn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a
LogData.Sourcefn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Sourcefn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>
fn decode_topics<I, D>( topics: I, ) -> Result<<Self::TopicList as SolType>::RustType, Error>
Decode the topics of this event from the given data.
Sourcefn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
Sourcefn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer, with validation. Read more
Sourcefn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info.
Sourcefn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>
Decode the event from the given log info, with validation. Read more
Sourcefn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object.
Sourcefn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object with validation.