pub struct increaseCardinalityCapCall {
pub perpId: FixedBytes<32>,
pub newCardinalityCap: u16,
}Expand description
Increases the oracle cardinality cap for a perp.
Function with signature increaseCardinalityCap(bytes32,uint16) and selector 0x6bb00ff2.
function increaseCardinalityCap(bytes32 perpId, uint16 newCardinalityCap) external;Fields
perpId: FixedBytes<32>newCardinalityCap: u16Trait Implementations
Sourceimpl Clone for increaseCardinalityCapCall
impl Clone for increaseCardinalityCapCall
Sourcefn clone(&self) -> increaseCardinalityCapCall
fn clone(&self) -> increaseCardinalityCapCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for increaseCardinalityCapCall
impl SolCall for increaseCardinalityCapCall
Sourceconst SIGNATURE: &'static str = "increaseCardinalityCap(bytes32,uint16)"
const SIGNATURE: &'static str = "increaseCardinalityCap(bytes32,uint16)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, Uint<16>)
type Parameters<'a> = (FixedBytes<32>, Uint<16>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<increaseCardinalityCapCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<increaseCardinalityCapCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = increaseCardinalityCapReturn
type Return = increaseCardinalityCapReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<increaseCardinalityCapCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<increaseCardinalityCapCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.