pub struct quoteSwapCall {
pub perpId: FixedBytes<32>,
pub zeroForOne: bool,
pub isExactIn: bool,
pub amount: U256,
pub sqrtPriceLimitX96: U160,
}Expand description
Simulates a swap in a perp’s Uniswap V4 pool.
Function with signature quoteSwap(bytes32,bool,bool,uint256,uint160) and selector 0x1ab15249.
function quoteSwap(bytes32 perpId, bool zeroForOne, bool isExactIn, uint256 amount, uint160 sqrtPriceLimitX96) external returns (bytes memory unexpectedReason, int256 perpDelta, int256 usdDelta);Fields
perpId: FixedBytes<32>zeroForOne: boolisExactIn: boolamount: U256sqrtPriceLimitX96: U160Trait Implementations
Sourceimpl Clone for quoteSwapCall
impl Clone for quoteSwapCall
Sourcefn clone(&self) -> quoteSwapCall
fn clone(&self) -> quoteSwapCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for quoteSwapCall
impl SolCall for quoteSwapCall
Sourceconst SIGNATURE: &'static str = "quoteSwap(bytes32,bool,bool,uint256,uint160)"
const SIGNATURE: &'static str = "quoteSwap(bytes32,bool,bool,uint256,uint160)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, Bool, Bool, Uint<256>, Uint<160>)
type Parameters<'a> = (FixedBytes<32>, Bool, Bool, Uint<256>, Uint<160>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<quoteSwapCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<quoteSwapCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = quoteSwapReturn
type Return = quoteSwapReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Bytes, Int<256>, Int<256>)
type ReturnTuple<'a> = (Bytes, Int<256>, Int<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<quoteSwapCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<quoteSwapCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.