pub struct quoteTwoSwapsCall {
pub perpId: FixedBytes<32>,
pub first: <SwapConfig as SolType>::RustType,
pub second: <SwapConfig as SolType>::RustType,
}Expand description
Simulates two sequential swaps.
Function with signature quoteTwoSwaps(bytes32,((address,address,uint24,int24,address),bool,bool,uint256,uint160,uint128),((address,address,uint24,int24,address),bool,bool,uint256,uint160,uint128)) and selector 0xed267197.
function quoteTwoSwaps(bytes32 perpId, SwapConfig memory first, SwapConfig memory second) external returns (bytes memory unexpectedReason, int256 perpDelta1, int256 usdDelta1, int256 perpDelta2, int256 usdDelta2);Fields
perpId: FixedBytes<32>first: <SwapConfig as SolType>::RustTypesecond: <SwapConfig as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for quoteTwoSwapsCall
impl Clone for quoteTwoSwapsCall
Sourcefn clone(&self) -> quoteTwoSwapsCall
fn clone(&self) -> quoteTwoSwapsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for quoteTwoSwapsCall
impl SolCall for quoteTwoSwapsCall
Sourceconst SIGNATURE: &'static str = "quoteTwoSwaps(bytes32,((address,address,uint24,int24,address),bool,bool,uint256,uint160,uint128),((address,address,uint24,int24,address),bool,bool,uint256,uint160,uint128))"
const SIGNATURE: &'static str = "quoteTwoSwaps(bytes32,((address,address,uint24,int24,address),bool,bool,uint256,uint160,uint128),((address,address,uint24,int24,address),bool,bool,uint256,uint160,uint128))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, SwapConfig, SwapConfig)
type Parameters<'a> = (FixedBytes<32>, SwapConfig, SwapConfig)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<quoteTwoSwapsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<quoteTwoSwapsCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = quoteTwoSwapsReturn
type Return = quoteTwoSwapsReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = (Bytes, Int<256>, Int<256>, Int<256>, Int<256>)
type ReturnTuple<'a> = (Bytes, Int<256>, Int<256>, Int<256>, Int<256>)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<quoteTwoSwapsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<quoteTwoSwapsCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.