PerpManagerInstance

Struct PerpManagerInstance 

pub struct PerpManagerInstance<P, N = Ethereum> { /* private fields */ }
A PerpManager instance.

Contains type-safe methods for interacting with an on-chain instance of the PerpManager contract located at a given address, using a given provider P.

If the contract bytecode is available (see the sol! documentation on how to provide it), the deploy and deploy_builder methods can be used to deploy a new instance of the contract.

See the module-level documentation for all the available methods.

Implementations

Source

impl<P: Provider<N>, N: Network> PerpManagerInstance<P, N>

Instantiation and getters/setters.

pub const fn new(address: Address, __provider: P) -> Self

Creates a new wrapper around an on-chain PerpManager contract instance.

See the wrapper’s documentation for more details.

pub const fn address(&self) -> &Address

Returns a reference to the address.

pub fn set_address(&mut self, address: Address)

Sets the address.

pub fn at(self, address: Address) -> Self

Sets the address and returns self.

pub const fn provider(&self) -> &P

Returns a reference to the provider.

Source

impl<P: Clone, N> PerpManagerInstance<&P, N>

pub fn with_cloned_provider(self) -> PerpManagerInstance<P, N>

Clones the provider and returns a new instance with the cloned provider.

Source

impl<P: Provider<N>, N: Network> PerpManagerInstance<P, N>

Function calls.

pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>

Creates a new call builder using this contract instance’s provider and address.

Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.

pub fn createPerp( &self, params: <CreatePerpParams as SolType>::RustType, ) -> SolCallBuilder<&P, createPerpCall, N>

Creates a new call builder for the [createPerp] function.

pub fn openMakerPos( &self, perpId: FixedBytes<32>, params: <OpenMakerPositionParams as SolType>::RustType, ) -> SolCallBuilder<&P, openMakerPosCall, N>

Creates a new call builder for the [openMakerPos] function.

pub fn openTakerPos( &self, perpId: FixedBytes<32>, params: <OpenTakerPositionParams as SolType>::RustType, ) -> SolCallBuilder<&P, openTakerPosCall, N>

Creates a new call builder for the [openTakerPos] function.

pub fn adjustNotional( &self, params: <AdjustNotionalParams as SolType>::RustType, ) -> SolCallBuilder<&P, adjustNotionalCall, N>

Creates a new call builder for the [adjustNotional] function.

pub fn adjustMargin( &self, params: <AdjustMarginParams as SolType>::RustType, ) -> SolCallBuilder<&P, adjustMarginCall, N>

Creates a new call builder for the [adjustMargin] function.

pub fn closePosition( &self, params: <ClosePositionParams as SolType>::RustType, ) -> SolCallBuilder<&P, closePositionCall, N>

Creates a new call builder for the [closePosition] function.

pub fn increaseCardinalityCap( &self, perpId: FixedBytes<32>, newCardinalityCap: u16, ) -> SolCallBuilder<&P, increaseCardinalityCapCall, N>

Creates a new call builder for the [increaseCardinalityCap] function.

pub fn registerFeesModule( &self, feesModule: Address, ) -> SolCallBuilder<&P, registerFeesModuleCall, N>

Creates a new call builder for the [registerFeesModule] function.

pub fn registerMarginRatiosModule( &self, marginRatiosModule: Address, ) -> SolCallBuilder<&P, registerMarginRatiosModuleCall, N>

Creates a new call builder for the [registerMarginRatiosModule] function.

pub fn registerLockupPeriodModule( &self, lockupPeriodModule: Address, ) -> SolCallBuilder<&P, registerLockupPeriodModuleCall, N>

Creates a new call builder for the [registerLockupPeriodModule] function.

pub fn registerSqrtPriceImpactLimitModule( &self, sqrtPriceImpactLimitModule: Address, ) -> SolCallBuilder<&P, registerSqrtPriceImpactLimitModuleCall, N>

Creates a new call builder for the [registerSqrtPriceImpactLimitModule] function.

pub fn isFeesRegistered( &self, feesModule: Address, ) -> SolCallBuilder<&P, isFeesRegisteredCall, N>

Creates a new call builder for the [isFeesRegistered] function.

pub fn isMarginRatiosRegistered( &self, marginRatiosModule: Address, ) -> SolCallBuilder<&P, isMarginRatiosRegisteredCall, N>

Creates a new call builder for the [isMarginRatiosRegistered] function.

pub fn isLockupPeriodRegistered( &self, lockupPeriodModule: Address, ) -> SolCallBuilder<&P, isLockupPeriodRegisteredCall, N>

Creates a new call builder for the [isLockupPeriodRegistered] function.

pub fn isSqrtPriceImpactLimitRegistered( &self, sqrtPriceImpactLimitModule: Address, ) -> SolCallBuilder<&P, isSqrtPriceImpactLimitRegisteredCall, N>

Creates a new call builder for the [isSqrtPriceImpactLimitRegistered] function.

pub fn setProtocolFee( &self, newProtocolFee: U24, ) -> SolCallBuilder<&P, setProtocolFeeCall, N>

Creates a new call builder for the [setProtocolFee] function.

pub fn collectProtocolFees( &self, recipient: Address, ) -> SolCallBuilder<&P, collectProtocolFeesCall, N>

Creates a new call builder for the [collectProtocolFees] function.

pub fn cfgs(&self, perpId: FixedBytes<32>) -> SolCallBuilder<&P, cfgsCall, N>

Creates a new call builder for the [cfgs] function.

pub fn positions(&self, posId: U256) -> SolCallBuilder<&P, positionsCall, N>

Creates a new call builder for the [positions] function.

pub fn nextPosId(&self) -> SolCallBuilder<&P, nextPosIdCall, N>

Creates a new call builder for the [nextPosId] function.

pub fn protocolFee(&self) -> SolCallBuilder<&P, protocolFeeCall, N>

Creates a new call builder for the [protocolFee] function.

pub fn cardinalityCap( &self, perpId: FixedBytes<32>, ) -> SolCallBuilder<&P, cardinalityCapCall, N>

Creates a new call builder for the [cardinalityCap] function.

pub fn timeWeightedAvgSqrtPriceX96( &self, perpId: FixedBytes<32>, lookbackWindow: u32, ) -> SolCallBuilder<&P, timeWeightedAvgSqrtPriceX96Call, N>

Creates a new call builder for the [timeWeightedAvgSqrtPriceX96] function.

pub fn fundingPerSecondX96( &self, perpId: FixedBytes<32>, ) -> SolCallBuilder<&P, fundingPerSecondX96Call, N>

Creates a new call builder for the [fundingPerSecondX96] function.

pub fn utilFeePerSecX96( &self, perpId: FixedBytes<32>, ) -> SolCallBuilder<&P, utilFeePerSecX96Call, N>

Creates a new call builder for the [utilFeePerSecX96] function.

pub fn insurance( &self, perpId: FixedBytes<32>, ) -> SolCallBuilder<&P, insuranceCall, N>

Creates a new call builder for the [insurance] function.

pub fn takerOpenInterest( &self, perpId: FixedBytes<32>, ) -> SolCallBuilder<&P, takerOpenInterestCall, N>

Creates a new call builder for the [takerOpenInterest] function.

pub fn quoteOpenMakerPosition( &self, perpId: FixedBytes<32>, params: <OpenMakerPositionParams as SolType>::RustType, ) -> SolCallBuilder<&P, quoteOpenMakerPositionCall, N>

Creates a new call builder for the [quoteOpenMakerPosition] function.

pub fn quoteOpenTakerPosition( &self, perpId: FixedBytes<32>, params: <OpenTakerPositionParams as SolType>::RustType, ) -> SolCallBuilder<&P, quoteOpenTakerPositionCall, N>

Creates a new call builder for the [quoteOpenTakerPosition] function.

pub fn quoteClosePosition( &self, posId: U256, ) -> SolCallBuilder<&P, quoteClosePositionCall, N>

Creates a new call builder for the [quoteClosePosition] function.

pub fn quoteSwap( &self, perpId: FixedBytes<32>, zeroForOne: bool, isExactIn: bool, amount: U256, sqrtPriceLimitX96: U160, ) -> SolCallBuilder<&P, quoteSwapCall, N>

Creates a new call builder for the [quoteSwap] function.

pub fn quoteTwoSwaps( &self, perpId: FixedBytes<32>, first: <SwapConfig as SolType>::RustType, second: <SwapConfig as SolType>::RustType, ) -> SolCallBuilder<&P, quoteTwoSwapsCall, N>

Creates a new call builder for the [quoteTwoSwaps] function.

pub fn name(&self) -> SolCallBuilder<&P, nameCall, N>

Creates a new call builder for the [name] function.

pub fn symbol(&self) -> SolCallBuilder<&P, symbolCall, N>

Creates a new call builder for the [symbol] function.

pub fn tokenURI(&self, tokenId: U256) -> SolCallBuilder<&P, tokenURICall, N>

Creates a new call builder for the [tokenURI] function.

pub fn ownerOf(&self, tokenId: U256) -> SolCallBuilder<&P, ownerOfCall, N>

Creates a new call builder for the [ownerOf] function.

Source

impl<P: Provider<N>, N: Network> PerpManagerInstance<P, N>

Event filters.

pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>

Creates a new event filter using this contract instance’s provider and address.

Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.

pub fn PerpCreated_filter(&self) -> Event<&P, PerpCreated, N>

Creates a new event filter for the PerpCreated event.

pub fn PositionOpened_filter(&self) -> Event<&P, PositionOpened, N>

Creates a new event filter for the PositionOpened event.

pub fn NotionalAdjusted_filter(&self) -> Event<&P, NotionalAdjusted, N>

Creates a new event filter for the NotionalAdjusted event.

pub fn MarginAdjusted_filter(&self) -> Event<&P, MarginAdjusted, N>

Creates a new event filter for the MarginAdjusted event.

pub fn PositionClosed_filter(&self) -> Event<&P, PositionClosed, N>

Creates a new event filter for the PositionClosed event.

pub fn FeesModuleRegistered_filter(&self) -> Event<&P, FeesModuleRegistered, N>

Creates a new event filter for the FeesModuleRegistered event.

pub fn MarginRatiosModuleRegistered_filter( &self, ) -> Event<&P, MarginRatiosModuleRegistered, N>

Creates a new event filter for the MarginRatiosModuleRegistered event.

pub fn LockupPeriodModuleRegistered_filter( &self, ) -> Event<&P, LockupPeriodModuleRegistered, N>

Creates a new event filter for the LockupPeriodModuleRegistered event.

pub fn SqrtPriceImpactLimitModuleRegistered_filter( &self, ) -> Event<&P, SqrtPriceImpactLimitModuleRegistered, N>

Creates a new event filter for the SqrtPriceImpactLimitModuleRegistered event.